@@ -76,11 +76,9 @@ pub struct YaccGrammar<StorageT = u32> {
     implicit_rule: Option<RIdx<StorageT>>,
     /// User defined Rust programs which can be called within actions
     actions: Vec<Option<String>>,
-    /// Extra Parameters to the parse function, for user actions.
-    param_args: Vec<(String, String)>,
+    /// A `(name, type)` pair defining an extra parameter to pass to action functions.
+    parse_param: Option<(String, String)>,
     /// Lifetimes for `param_args`
-    param_lifetimes: Vec<String>,
-    /// The programs section of a grammar, if specified; otherwise `None`.
     programs: Option<String>,
     /// The actiontypes of rules (one per rule).
     actiontypes: Vec<Option<String>>,
@@ -316,7 +314,7 @@ where
         }
 
         let avoid_insert = if let Some(ai) = ast.avoid_insert {
-            let mut aiv = Vob::from_elem(token_names.len(), false);
+            let mut aiv = Vob::from_elem(false, token_names.len());
             for n in ai.iter() {
                 aiv.set(usize::from(token_map[n]), true);
             }
@@ -343,13 +341,7 @@ where
             prod_precs: prod_precs.into_iter().map(Option::unwrap).collect(),
             implicit_rule: implicit_rule.map(|x| rule_map[&x]),
             actions,
-            param_args: ast.parse_param_bindings.iter().flatten().cloned().collect(),
-            param_lifetimes: ast
-                .parse_param_lifetimes
-                .iter()
-                .flatten()
-                .cloned()
-                .collect(),
+            parse_param: ast.parse_param,
             programs: ast.programs,
             avoid_insert,
             actiontypes,
@@ -492,12 +484,8 @@ where
         &self.actiontypes[usize::from(ridx)]
     }
 
-    pub fn param_args(&self) -> &Vec<(String, String)> {
-        &self.param_args
-    }
-
-    pub fn param_lifetimes(&self) -> &Vec<String> {
-        &self.param_lifetimes
+    pub fn parse_param(&self) -> &Option<(String, String)> {
+        &self.parse_param
     }
 
     /// Get the programs part of the grammar
